@@ -8,3 +8,8 @@ class Station(object):
         self.resource = ""
         self.bitrate = ""
 
+
+    def __cmp__(self, other):
+    
+        return cmp(self.name, other.name)
+
